/*
  Send F5 keycode every minute to browser to perform a screen refresh
  by M. Ray Burnette 20170617 MIT license
  ArduinoGUI 1.6.13
    Sketch uses 3,512 bytes (66%) of program storage space. Maximum is 5,310 bytes.
    Global variables use 105 bytes of dynamic memory.
*/

#include <TrinketKeyboard.h>

#define   PIN_F5    2            // force F5 via physical pin pulled to Gnd
unsigned long int  Poll;
unsigned long int  F5;
const unsigned int keyRefresh     = 60000; // 60 seconds
const unsigned int PollInterval   =     9; //  9 mS
const int LEDpin                  =     1;
boolean   PIND;

void setup()
{
  pinMode(LEDpin, OUTPUT); 
  digitalWrite(LEDpin, LOW); // low == off
  // button pins as inputs
  pinMode(PIN_F5, INPUT);
  // setting input pins to high means turning on internal pull-up resistors
  digitalWrite(PIN_F5, HIGH);


  // start USB stuff
  TrinketKeyboard.begin();
  TrinketKeyboard.typeChar(0);

  // Initialize timing variables
  Poll  = millis() + PollInterval;
  F5    = millis() + keyRefresh;
}

void loop()
{
  if( millis() > Poll)
  {
    Poll = millis() + PollInterval;
    TrinketKeyboard.poll();   // the poll function must be called at least once every 10 ms
                              // or cause a keystroke if it is not, then the computer may think
                              // that the device has stopped working, and give errors
  }

  if (digitalRead(PIN_F5) == LOW)
  {
    TrinketKeyboard.pressKey(0,KEYCODE_F5); // send the keystroke to refresh the current screen
    TrinketKeyboard.pressKey(0, 0);         // this releases the key
    PIND = !PIND; // flip boolean PIND
    digitalWrite(LEDpin, PIND);
  }

  if( millis() > F5 )
  {
    F5 = millis() + keyRefresh;
    TrinketKeyboard.pressKey(0, KEYCODE_F5);
    TrinketKeyboard.pressKey(0, 0);
    PIND = !PIND; // flip boolean PIND
    digitalWrite(LEDpin, PIND);
  }
}
